package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"D```````!``````````%#!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````,`9````````P!D`````````
M$`````````$````%`````"``````````(``````````@````````74(`````
M``!=0@`````````0`````````0````0`````<`````````!P`````````'``
M``````#P1@```````/!&`````````!`````````!````!@```,"[````````
MP,L```````#`RP```````&`$````````H!0`````````$`````````(````&
M````T+L```````#0RP```````-#+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``"4KP```````)2O````````E*\```````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````P+L```````#`RP```````,#+````
M````0`0```````!`!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`RM:$9M1D[F9P=P!'
M#6;F0::-F>T$````$`````$```!'3E4```````,````"```````````````1
M````1`````0````(````(!`0``5`!(0H`@`$@(8`A(()```)(`0(B(`10;H`
M`@@`````1````$<```!*````2P```%(```!3````5`````````!6````5P``
M`%@```!9````6P```%T``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@:PE#UF>OS&9"
M1=7LB0=PTS-BV^T5C"7,#3J7"WZIG)O19<YMX*<""FL:GE"CX/M)````````
M`````````````````````````````"("```2````````````````````````
M`+@"```2`````````````````````````.@````1````````````````````
M`````)H!```2`````````````````````````*("```2````````````````
M`````````(P````1``````````````````````````D"```2````````````
M`````````````#P!```2`````````````````````````(`"```2````````
M`````````````````,4!```2``````````````````````````$````@````
M`````````````````````%T"```2`````````````````````````&<````2
M`````````````````````````)T"```2`````````````````````````)0`
M```2``````````````````````````("```2````````````````````````
M`%0"```2`````````````````````````*@"```2````````````````````
M`````-(````2`````````````````````````.(````2````````````````
M`````````%(!```2`````````````````````````'`!```2````````````
M`````````````(H````1`````````````````````````'\#```2````````
M`````````````````!`````@`````````````````````````#H"```2````
M`````````````````````"<"```2`````````````````````````+T````2
M`````````````````````````"P````@`````````````````````````)T`
M```2`````````````````````````*L````2````````````````````````
M`"P"```2``````````````````````````<!```2````````````````````
M`````-@!```2`````````````````````````"(!```2````````````````
M`````````$4"```2`````````````````````````(X"```2````````````
M`````````````*\!```2`````````````````````````$,!```2````````
M`````````````````#,!```2`````````````````````````&`!```2````
M`````````````````````'X!```2`````````````````````````!0"```2
M`````````````````````````&@"```2`````````````````````````(4!
M```2`````````````````````````-D"```2````````````````````````
M`'D````2`````````````````````````),!```2````````````````````
M`````(P!```2`````````````````````````)P````2````````````````
M`````````*@!```2`````````````````````````/,````2````````````
M`````````````,0"```2`````````````````````````/8!```2````````
M`````````````````)4"```2`````````````````````````-D````2````
M`````````````````````,0````2`````````````````````````'D"```1
M`````````````````````````.D!```1`````````````````````````*0`
M```2`````````````````````````&@!```2````````````````````````
M`!<!```2`````````````````````````+8!```2````````````````````
M`````%4````2`````````````````````````'<!```2````````````````
M`````````+,````2`````````````````````````&("```2````````````
M`````````````(@#```2`!``D%(````````&`0```````-T#```2`!``,%<`
M``````"""````````&(````2`!``("<````````R`@```````/\"```2`!``
M($@````````)`````````!T#```2`!``P%\```````!Y`@````````,$```2
M`!``,$@````````2`@```````,,#```0`!H`(-```````````````````!`#
M```2`!``4$H````````E`````````#,#```2`!``<%````````!\````````
M`)0#```1`!(``'`````````$`````````+`#```2`!``H%,```````"?`0``
M`````+L#```2`!```$<````````W`````````-@#```0`!H`8.``````````
M`````````/$#```2`!``(%$````````+`0```````*,#```0`!D``-``````
M`````````````%<#```2`!``@$H```````#<`````````.H#```0`!D`(-``
M`````````````````!`$```1`!D`&-`````````(`````````*D#```2`!``
M8"D````````F`````````,\#```2`!``,%(```````!8`````````*4#```@
M`!D``-```````````````````&T#```2`!``\%`````````A`````````$8`
M```B`````````````````````````$$#```2`!``0$<```````#8````````
M`&,#```2`!``0%4```````#K`0```````!H$```2`!``8$L````````$!0``
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7V-X85]F:6YA;&EZ90!?
M7VQI8F-?<W1A<G1?;6%I;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H
M:U]F86EL`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD
M:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S
M961I<@!R;61I<@!03%]T:')?:V5Y`'!T:')E861?9V5T<W!E8VEF:6,`8F]O
M=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D
M;&EN:P!M96UC:'(`4&5R;%]S=E]S971P=FX`4&5R;%]S=E]S971P=@!M96UM
M;W9E`')E86QL;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R9'5P`'-T<G1O
M:P!S=')C;7``7U]S=')N8W!Y7V-H:P!G971U:60`<W1R<W1R`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,
M7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L
M7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`
M<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`97AI=`!M:V1I<@!?7V5R<FYO7VQO
M8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P96XV-`!L<V5E:S8T`')E
M860`8VQO<V4`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`&QI8G!E<FPN<V\N-2XS-`!L:6)C
M+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A
M<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E
M;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,
M24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)
M0D-?,BXR+C4`1TQ)0D-?,BXS+C0````!``$``0`"``,``P`!``,``@`!``$`
M`P`$``,``P`#``$``0`#``,``0`#``,``P`!``$``P`#``$`!0`#``$``0`!
M``$``0`#``,``0`#``,``P`!``,``P`!``8``P`#``4``P`'``$``0`#``,`
M`@`#``$``P`#``$``0`'``@``P`#``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``P`!``$``0`````````!``<`]0(``!``
M````````E)&6!@``"``G!```$````+21E@8```<`,@0``!`````4:6D-```&
M`#T$```0````LY&6!@``!0!'!```$````'(9:0D```0`4@0``!````!U&FD)
M```#`%X$```0````=!EI"0```@!J!````````,#+````````"`````````!`
M*@```````,C+````````"```````````*@````````C0````````"```````
M```(T````````!C0````````"`````````#8<@```````*#/````````!@``
M``,``````````````*C/````````!@````8``````````````+#/````````
M!@````H``````````````+C/````````!@````L``````````````,#/````
M````!@```!D``````````````,C/````````!@```!T``````````````-#/
M````````!@```%H``````````````-C/````````!@```"$`````````````
M`.#/````````!@```"(``````````````.C/````````!@```#H`````````
M`````/#/````````!@```#L``````````````/C/````````!@```$``````
M`````````.C-````````!P````$``````````````/#-````````!P````(`
M`````````````/C-````````!P````0```````````````#.````````!P``
M``4```````````````C.````````!P````<``````````````!#.````````
M!P````@``````````````!C.````````!P````D``````````````"#.````
M````!P````P``````````````"C.````````!P````T``````````````##.
M````````!P````X``````````````#C.````````!P````\`````````````
M`$#.````````!P```!```````````````$C.````````!P```!$`````````
M`````%#.````````!P```!(``````````````%C.````````!P```!,`````
M`````````&#.````````!P```!0``````````````&C.````````!P```!4`
M`````````````'#.````````!P```!8``````````````'C.````````!P``
M`!@``````````````(#.````````!P```!H``````````````(C.````````
M!P```!L``````````````)#.````````!P```!P``````````````)C.````
M````!P```!X``````````````*#.````````!P```!\``````````````*C.
M````````!P```"```````````````+#.````````!P```",`````````````
M`+C.````````!P```"0``````````````,#.````````!P```"4`````````
M`````,C.````````!P```"8``````````````-#.````````!P```"<`````
M`````````-C.````````!P```"@``````````````.#.````````!P```"D`
M`````````````.C.````````!P```"H``````````````/#.````````!P``
M`"L``````````````/C.````````!P```"P```````````````#/````````
M!P```"T```````````````C/````````!P```"X``````````````!#/````
M````!P```"\``````````````!C/````````!P```#```````````````"#/
M````````!P```#$``````````````"C/````````!P```#(`````````````
M`##/````````!P```#,``````````````#C/````````!P```#0`````````
M`````$#/````````!P```#4``````````````$C/````````!P```#8`````
M`````````%#/````````!P```#<``````````````%C/````````!P```#@`
M`````````````&#/````````!P```#D``````````````&C/````````!P``
M`#P``````````````'#/````````!P```#T``````````````'C/````````
M!P```#X``````````````(#/````````!P```#\``````````````(C/````
M````!P```$$``````````````)#/````````!P```$(``````````````)C/
M````````!P```$,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:FO``!(A<!T`O_02(/$",,``````/\ULJT``/+_);.M
M```/'P#S#Q[Z:`````#RZ>'___^0\P\>^F@!````\NG1____D/,/'OIH`@``
M`/+IP?___Y#S#Q[Z:`,```#RZ;'___^0\P\>^F@$````\NFA____D/,/'OIH
M!0```/+ID?___Y#S#Q[Z:`8```#RZ8'___^0\P\>^F@'````\NEQ____D/,/
M'OIH"````/+I8?___Y#S#Q[Z:`D```#RZ5'___^0\P\>^F@*````\NE!____
MD/,/'OIH"P```/+I,?___Y#S#Q[Z:`P```#RZ2'___^0\P\>^F@-````\ND1
M____D/,/'OIH#@```/+I`?___Y#S#Q[Z:`\```#RZ?'^__^0\P\>^F@0````
M\NGA_O__D/,/'OIH$0```/+IT?[__Y#S#Q[Z:!(```#RZ<'^__^0\P\>^F@3
M````\NFQ_O__D/,/'OIH%````/+IH?[__Y#S#Q[Z:!4```#RZ9'^__^0\P\>
M^F@6````\NF!_O__D/,/'OIH%P```/+I<?[__Y#S#Q[Z:!@```#RZ6'^__^0
M\P\>^F@9````\NE1_O__D/,/'OIH&@```/+I0?[__Y#S#Q[Z:!L```#RZ3'^
M__^0\P\>^F@<````\NDA_O__D/,/'OIH'0```/+I$?[__Y#S#Q[Z:!X```#R
MZ0'^__^0\P\>^F@?````\NGQ_?__D/,/'OIH(````/+IX?W__Y#S#Q[Z:"$`
M``#RZ=']__^0\P\>^F@B````\NG!_?__D/,/'OIH(P```/+IL?W__Y#S#Q[Z
M:"0```#RZ:']__^0\P\>^F@E````\NF1_?__D/,/'OIH)@```/+I@?W__Y#S
M#Q[Z:"<```#RZ7']__^0\P\>^F@H````\NEA_?__D/,/'OIH*0```/+I4?W_
M_Y#S#Q[Z:"H```#RZ4']__^0\P\>^F@K````\NDQ_?__D/,/'OIH+````/+I
M(?W__Y#S#Q[Z:"T```#RZ1']__^0\P\>^F@N````\ND!_?__D/,/'OIH+P``
M`/+I\?S__Y#S#Q[Z:#````#RZ>'\__^0\P\>^F@Q````\NG1_/__D/,/'OIH
M,@```/+IP?S__Y#S#Q[Z:#,```#RZ;'\__^0\P\>^F@T````\NFA_/__D/,/
M'OIH-0```/+ID?S__Y#S#Q[Z:#8```#RZ8'\__^0\P\>^O+_)26L```/'T0`
M`/,/'OKR_R4MJ@``#Q]$``#S#Q[Z\O\E):H```\?1```\P\>^O+_)1VJ```/
M'T0``/,/'OKR_R45J@``#Q]$``#S#Q[Z\O\E#:H```\?1```\P\>^O+_)06J
M```/'T0``/,/'OKR_R7]J0``#Q]$``#S#Q[Z\O\E]:D```\?1```\P\>^O+_
M)>VI```/'T0``/,/'OKR_R7EJ0``#Q]$``#S#Q[Z\O\EW:D```\?1```\P\>
M^O+_)=6I```/'T0``/,/'OKR_R7-J0``#Q]$``#S#Q[Z\O\EQ:D```\?1```
M\P\>^O+_);VI```/'T0``/,/'OKR_R6UJ0``#Q]$``#S#Q[Z\O\EK:D```\?
M1```\P\>^O+_):6I```/'T0``/,/'OKR_R6=J0``#Q]$``#S#Q[Z\O\EE:D`
M``\?1```\P\>^O+_)8VI```/'T0``/,/'OKR_R6%J0``#Q]$``#S#Q[Z\O\E
M?:D```\?1```\P\>^O+_)76I```/'T0``/,/'OKR_R5MJ0``#Q]$``#S#Q[Z
M\O\E9:D```\?1```\P\>^O+_)5VI```/'T0``/,/'OKR_R55J0``#Q]$``#S
M#Q[Z\O\E3:D```\?1```\P\>^O+_)46I```/'T0``/,/'OKR_R4]J0``#Q]$
M``#S#Q[Z\O\E-:D```\?1```\P\>^O+_)2VI```/'T0``/,/'OKR_R4EJ0``
M#Q]$``#S#Q[Z\O\E':D```\?1```\P\>^O+_)16I```/'T0``/,/'OKR_R4-
MJ0``#Q]$``#S#Q[Z\O\E!:D```\?1```\P\>^O+_)?VH```/'T0``/,/'OKR
M_R7UJ```#Q]$``#S#Q[Z\O\E[:@```\?1```\P\>^O+_)>6H```/'T0``/,/
M'OKR_R7=J```#Q]$``#S#Q[Z\O\EU:@```\?1```\P\>^O+_)<VH```/'T0`
M`/,/'OKR_R7%J```#Q]$``#S#Q[Z\O\EO:@```\?1```\P\>^O+_);6H```/
M'T0``/,/'OKR_R6MJ```#Q]$``#S#Q[Z\O\EI:@```\?1```\P\>^O+_)9VH
M```/'T0``/,/'OKR_R65J```#Q]$``#S#Q[Z\O\EC:@```\?1```\P\>^O+_
M)86H```/'T0``/,/'OKR_R5]J```#Q]$``#S#Q[Z05152(/L.(E\)!Q(C7PD
M'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP.B#____2(LU
M3*@``$B+/76H``!(B?+HS3H``$B+!7:H``"`.``/A#,!``!,BR46J```08L\
M).B]_O__08L\)("(*@0```+HK?[__X"(*@0```&+1"0<C7@$1(U@`TAC_TC!
MYP/HK_[__TB+3"00BW0D'$F)P4B)!82H``!(BP%)B0%(C05220``28E!"$B-
M!2RH``!(BP!)B4$02(T%/$D``$F)01B#_@$/CC(!``!(@\$(@\8#N`0````/
M'T0``$B+.4ACT(/``4B#P0A)B3S1.<9UZTAC]DB+/1&H``!$B>)%,<!)QP3Q
M`````$R)R4B--0$;``#HG/O__T&)Q(7`#X2,````2(L]XJ<``$B-;"0DZ%#]
M__\QP$B)[DB-/2=(``#H_Q<``$B%P'1Y2(L]NZ<``.@>^___Z)G\__](BT0D
M*&1(*P0E*`````^%H@```$B#Q#A$B>!=05S#Z"7\__](B06&IP``2(G'2(7`
M='GH@?S__TR+)<JF``!!BSPDZ'']___&@-<)````Z9_^__](BSU6IP``Z'G[
M__]!B<3I8/___TB+/4JG``!(A?]T"NB`*0``Z7'___](C3T\1P``2(GNZ%P7
M``!(B04EIP``2(G'2(7`#X1/____Z]*^!````.GJ_O__OP$```#HT_K__^BN
M_/__9BX/'X0```````\?0`#S#Q[Z,>U)B=%>2(GB2(/D\%!413'`,<E(C3VA
M_?___Q5SI@``]&8N#Q^$``````!(C3V)I@``2(T%@J8``$@Y^'052(L%%J8`
M`$B%P'0)_^`/'X``````PP\?@`````!(C3U9I@``2(TU4J8``$@I_DB)\$C!
M[C](P?@#2`'&2-'^=!1(BP7=I0``2(7`=`C_X&8/'T0``,,/'X``````\P\>
M^H`]%:8```!U*U5(@SVZI0```$B)Y70,2(L]YJ4``.AY^?__Z&3____&!>VE
M```!7<,/'P###Q^``````/,/'OKI=____P\?@`````!!5TB)_DR-3SA!5D%5
M05154TB![)@"``!D2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(````!)B=`/
M'X``````08L!28LY28/`$$F#P0@/R(G`2(GY28E`\$B)^$C!Z2!(P>@H2,'O
M."4`_P``2`GX2(G/2,'A"$C!YQB!X0``_P")_T@)^$@)R$F)0/A-.=!UKDB-
MN@`"```/'X``````2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@
M_TB)0GA(.?IUU4R+#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(
MP>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH
M2,'H`DC!XAY)B?I("<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)
MT4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"
MB<%((?I,,<),`=)-B>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-
MA"B9>8):2`GZ38G52#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@
M00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(
M,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)
MTDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!
MZ`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)
MP>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'0
M2<'M&XG12"'X3#'`3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%
MB=)/C80HF7F"6D@)^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,
MBVPD2$$!T$R)XDG![`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G4
M3"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY
M@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,
MB<))P>@"2,'B'HG_3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@
M28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)
MY4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(
MP>(>18G23XV$*)EY@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%
M30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M
M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-
MO"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD
M@`````''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@A
MRDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-
ME"*9>8):38GL2#'02<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````
M00'"2(GX2,'@'DC![P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@Q
MRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````
M3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G1
M2<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ
M2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,
M">))B<R)R4@#C"2P````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)
MP(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL
M.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)
MB<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!
MZ`)(P>(>18GB3`G"28G(2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'K
MV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)
MTD@#E"30````2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',
M3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(
MB?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQ
MT$@#C"3@````13'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX
M2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,
MB<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P
M````23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H
M`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(
M`XPD^````$P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``
M2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!
MX1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;
M2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"A
MZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%
MB>!("?A(B=>)TD@#E"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A
M!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B
M3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),
M"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)
M^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$
M2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)
MP$TQXHG/2`.$)#@!``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'2
M3(G"2<'H`DC!XAY%B=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9
M;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A
M^DTAUDD)UDB+E"1``0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,
MB=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&
M30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)
MP4&)R$D)SDTAYDPAPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!
MYP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D
M6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!
MX1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)
MT$G!X`5)P>X;30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPA
MT4P)\4R+M"1H`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,
MB=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U
M38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)
MUD&)T$TAUDPAX4P)\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,
M"?=)B=8!STR)X4G![`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$`
M`$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),
M">I("=%)B=9!B=5((?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G!
M[AM)P>`%30GP28G600'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)
M\DR+M"20`0``20'&30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"
M2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF
M3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)
MSDTAYDPAPDP)\DR+M"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!
MUTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!
MQDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),
M">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)
MP>`%30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+
MM"2X`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"
M2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J
M38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTA
MT$PAX4P)P4R+A"3(`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y
M3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!
MT4V)PD@#A"38`0``2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>
M08G23`GI2`G/28G-08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G5
M2,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+
ME"3@`0``2`'"3`'B38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)
MP>H"20''30GB38G$B=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)
MS$G![AM)P>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!
MQDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"
M2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A
M!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,
M`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)
MP>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ
M2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-
M,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)
MP>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA
M2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),
M`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>
M2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G2
M2<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,
M`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"
M2,'B'D6)QDP)TDR+E"0X`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A
M!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,
M`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"
M2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ
M2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))
M`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)
MP>T"2,'B'D6)X$P)ZDR+K"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!
M2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),
M`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!
MT4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$
M1#'G38G42`'73(G22<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&
M2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!
MX4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':
M3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B480
M2(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^B`Y?__05=!
M5D%505154TB#[`A(A?\/A+$```!(BP4*CP``3(LH387M#X2>````#[8'28G_
M2(GUA,!T!#P]=55%,?9-BV4`387D="]-8_9,B>L/'P!,B?),B?Y,B>?H<N/_
M_X7`=0=#@#PT/71'3(MC"$B#PPA-A>1UVDB#Q`A,B>!;74%<05U!7D%?PP\?
MA```````28G^00^V1@%)@\8!A,!T!#P]=>]%*?[KE0\?@`````!,*>M/C60T
M`4C!^P.)70#KM0\?@`````!%,>3KJ0\?`%5(B?U(@>R@````9$B+!"4H````
M2(F$))@````QP$B)YNBZY/__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*``
M`'4>O@(```!(B>_H#^7__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4
M)2@```!U"4B!Q*````!=P^@MY/__9F8N#Q^$``````!FD$%6055!5%532('L
MH````&1(BP0E*````$B)A"28````,<!(A?]T"(`_`$B)_74Q2(N$))@```!D
M2"L$)2@````/A2$!``!(@<2@````6UU!7$%=05[#9BX/'X0``````.C;XO__
M3(TMN"T``$F)Q$B%P'2[3(GGZ*3D__](A<`/A*,```"`>!,N2(U8$W4)@'L!
M`'3?#Q\`@'@3+@^$G@```$B)[^AVXO__2(G?28G&Z&OB__]!C7P&`DAC_^B^
MX?__28G928GH3(GI28G&2(G'O@$````QP$C'PO_____HW./__TR)]TB)YNA!
MXO__3(GW@_C_=!"+1"08)0#P```]`$```'19Z*3A__],B??H_.'__TR)Y^@$
MY/__2(7`#X5@____#Q\`3(GGZ(#C__](B>_HB.'__^GR_O__#Q\`@'L!+@^%
M6/___X![`@`/A"#____I2?___P\?@`````#HF_[__^NEZ+3B__\/'T``\P\>
M^E-(BQU$C```BSOH[>+__XL[Z.;B__](BQ5GC```2(T-$&P``$B--8LL``!(
MB<?H2>/__XL[Z,+B__],C041+@``13')6TB-%2`<``!(B<=,B<%(C35Y+```
MZ8[A__]F9BX/'X0```````\?`$%6055!5%5(@>P`$```2(,,)`!(@^P8NO\/
M``!D2(L$)2@```!(B80D"!```#'`28GE2(G]28GT2(T]/"P``$R)[NB)X?__
MA<!^58U0_TQC\D*`/#0`#X6$````A=)T0$R)\KXO````3(GOZ-#?__](A<!T
M*TB+!62+``"+..@-XO__3(GQ3(GJ2(GN2(G'Z"SA___K)F8N#Q^$``````!(
MBP4YBP``BSCHXN'__TR)XDB)[DB)Q^@TX/__2(N$)`@0``!D2"L$)2@```!U
M&4B!Q!@0``!=05Q!74%>PV:03&/PZ7C____H4^'__P\?`$%7059!54%454B)
M]5-(B?M(@^PH9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'%2(GOZ!G@__](
MC70D%$B)WTF)Q#'`Z(?[__](A<`/A`8!``!(B<=)B<7H\]___TDYQ`^&T@``
M`$AC3"043(LUAHH``$R-/,T`````#[8#A,`/A*,!```\/0^$FP$``$B)V`^V
M4`%(@\`!A-)T!8#Z/77O2"G82)A-BRY*C7P@`NC]WO__30']28E%`$B%P'12
M28L&2(U+`4J+%#@/M@.(`H3`="(\/74-ZQP/'X``````A,!T$0^V`4B#P@%(
M@\$!B`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+1"089$@K
M!"4H````#X47`0``2(/$*%M=05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!
MB%0%`$B#P`&$TG7NZ[T/'T``3(LUF8D``$V+!DF#.``/A,,```!,B<!%,>UF
M#Q]$``!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+!?>)``"%P'5C2(GW
M3(E$)`C'!>&)```!````Z/S=__](B<=(A<`/A%'___])8\U(BW0D"$R-/,T`
M````3(GZZ!C?__])B09(B<=!C44!1(EL)!1(F$C'!,<`````Z83^__]F+@\?
MA```````3(G'Z`C@__])B09(B<=(A<`/A/K^__])8\U,C3S-`````.NZ#Q]`
M`#'`Z7?^__^^$````$4Q[>E7____Z`_?__]F9BX/'X0```````\?0`#S#Q[Z
M2(/L"$B+!9&(``"+..@ZW___2(L5NX@``$B#Q`A(C0U@:```2(G'2(TUV"@`
M`.F9W___9@\?A```````\P\>^D%455-(@>P`$```2(,,)`!(@>P`$```2(,,
M)`!(@^P@9$B+!"4H````2(F$)!@@```QP$B-K"00$```28GDZ#G=__],C0VX
M*```N@$0``!(B>]!B<!(C0VJ*```O@$````QP.CTWO__N@`0``!,B>9(B>_H
MU-W__T4QP(7`>"Z->`%(B<-(8__HC]S__TF)P$B%P'082&/;3(GF2(G'2(G:
MZ`;?___&!!@`28G`2(N$)!@@``!D2"L$)2@```!U#TB!Q"`@``!,B<!;74%<
MP^CHW?__#Q^$``````#S#Q[ZZ1?___\/'X``````\P\>^D%7059!54%455-(
M@>P`$```2(,,)`!(@>S(````9$B+!"4H````2(F$)+@0```QP$B)_4F)]$B-
M/><G``!(C70D'.@%^/__OB\```!(B>](B</H)=W__TB%P'1`,<!(B>Y(C3W%
M)P``Z`_\__](B>A(BY0DN!```&1(*Q0E*`````^%@@$``$B!Q,@0``!;74%<
M05U!7D%?PP\?`$B)[^@HW/__3(GG3(TEC"<``$&)QNCVW/__3(GF2(G'Z"O=
M__])B<5(A<!TDT&-1@%!@'T``$R--5DH``")1"0,#X3&````9@\?A```````
M2(7;=!-,B>Y(B=_HX-S__X7`#X2$````3(GOZ,#;___K"68/'T0``,8"`(G!
M@^@!2&/03`'J@#HO=.T#3"0,@?G_#P``#X\E____3(V\)+````!,B?%-B>@Q
MP$B#[`BZ`!```+X!````3(G_54R-#=PF``#H!]W__TB-="0P3(G_Z&K;__]:
M687`=1"+1"0X)0#P```]`(```'143(GF,?_H6MS__TF)Q4B%P`^$OO[__T&`
M?0``#X5#____2(7;=`6`.RYT&4R-+6@F``"Y`0```.EC____#Q^$``````"`
M>P$`=+;KWP\?A```````O@$```!,B?_HD]S__X7`=9M,B?Y(C3TV)@``Z(#Z
M__],B?_HJ-O__^EG_O__Z+[;__]F9BX/'X0```````\?`/,/'OH/M@=)B?B$
MP'039I!(@\<!/"\/M@=,#T3'A,!U[TR)P,-F9BX/'X0``````/,/'OI(A?\/
MA,,```!5@#\`2(G]#X2>````Z&':__](C50%_T@YU7(0Z9<```!FD$B#Z@%(
M.=5T)8`Z+W3R2#G5#X-^````2(/J`4@YU70.@#HO="A(@^H!2#G5=?*`?0`O
M=%1(C3V%)0``7>GOVO__#Q^``````(`Z+W4)2(/J`4@YU7+R2"GJ,<!(C4H"
M2('Y`!```'<82(/"`;D`$```2(GN2(T]-84``.B@V/__7<-F#Q]$``!(C3T7
M)0``7>F;VO__2#G5=;/KD@\?0`!(C3W_)```Z83:__\/'T``\P\>^D%7059!
M54%455-(C1W])```2(/L&&1(BP0E*````$B)1"0(,<!(C6PD!&:0,<!(B>Y(
MB=_HX_3__TB%P'0^2(L%_X,``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?
M@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1V4)```9@\?A```````
M,<!(B>Y(B=_H@_3__TB%P'0^2(L%GX,``$AC5"0$2(L`2(T$T$B+4`A(B1!(
MA=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1T\)```9@\?
MA```````,<!(B>Y(B=_H(_3__TB%P'0^2(L%/X,``$AC5"0$2(L`2(T$T$B+
M4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1WE
M(P``9@\?A```````,<!(B>Y(B=_HP_/__TB%P'0^2(L%WX(``$AC5"0$2(L`
M2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$
M``!,C26,(P``9@\?A```````,<!(B>Y,B>?H8_/__TB%P'0^2(L%?X(``$AC
M5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7P
MZ[9F#Q]$``!(C1T\(P``9@\?A```````,<!(B>Y(B=_H`_/__TB%P'0^2(L%
M'X(``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)
M$$B%TG7PZ[9F#Q]$``!,C2V1(@``9@\?A```````,<!(B>Y,B>_HH_+__TB%
MP'0^2(L%OX$``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$``!,C3V((@``9@\?A```````,<!(B>Y,B?_H
M0_+__TB%P'0^2(L%7X$``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@```
M``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C34R(@``9@\?A```````,<!(
MB>Y,B??HX_'__TB%P'0^2(L%_X```$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)T
MSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1W<(0``9@\?A```
M````,<!(B>Y(B=_H@_'__TB%P'0^2(L%GX```$AC5"0$2(L`2(T$T$B+4`A(
MB1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1T:(0``
M9@\?A```````,<!(B>Y(B=_H(_'__TB%P'0^2(L%/X```$AC5"0$2(L`2(T$
MT$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(
MB>Y(C3TC(0``Z-'P__](B<9(A<!T"DR)]S'`Z._T__](B>Y(C3T3(0``,<#H
MKO#__TB)QDB%P'0.2(T]#R$``#'`Z,CT__](B>Y(C3T)(0``,<#HA_#__TB)
MQDB%P'0Y3(GO,<#HI?3__TB+1"0(9$@K!"4H````=41(@\083(GG2(TU\R``
M`#'`6UU!7$%=05Y!7^EV]/__2(GN2(T]QR```#'`Z#7P__](B<9(A<!TN$R)
M_S'`Z%/T___KK.B<U?__9F8N#Q^$``````"0\P\>^DB#[!AD2(L$)2@```!(
MB40D"(L%A'\``(/X_W0?2(M4)`AD2"L4)2@```!U1DB#Q!C#9BX/'X0`````
M`$B-="0$2(T]\Q\``#'`Z+WO__](B<(QP$B%TG02#[8"/#`/E<*$P`^5P`^V
MP"'0B04K?P``ZZKH%-7__P\?0`#S#Q[Z2(/L".A#U?__B<?HS-/__TB%P'0#
M2(L`2(/$",-F9BX/'X0```````\?0`#S#Q[Z055!5$R-)>\?``!52(G]3(GG
M4TB#[!AD2(L$)2@```!(B40D"#'`2(UT)`3H*^___TB%P'0(@#@`2(G#=2Y(
MBT0D"&1(*P0E*`````^%L````$B)[DB#Q!A,B><QP%M=05Q!7>DC\___#Q\`
M2(GN2(G'Z-73__](A<!T($B+1"0(9$@K!"4H````=79(@\086UU!7$%=PP\?
M1```2(GOZ#C3__](B=])B<7H+=/__TF-?`4"Z(/2__](@^P(28GHO@$```!3
M2,?"_____TB)QTF)Q4R-#7`>``!(C0UA'P``,<#HE-3__UA:2(M$)`AD2"L$
M)2@```!U"$R)[NE3____Z-73__\/'T0``/,/'OI(@^P(OX````#H'M+__[J)
MJ\WON?[<NIB^\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`
M````2,=`,`````#'0'@`````2(/$",,/'X0``````/,/'OI!5$F)_%532(/L
M$&1(BP0E*````$B)1"0(,<#HS/?__P^V$$B)Q832=!1FD$B#P`&`^B\/MA!(
M#T3HA-)U[HL%.'T``$V%Y`^5PX/X_W1MA<`/E<`APX3;=2)(BT0D"&1(*P0E
M*`````^%CP```$B#Q!!;74%<PP\?1```08`\)`!TU[H$````2(TU"QX``$B)
M[^@ET?__A<!UOTB+1"0(9$@K!"4H````=5)(@\003(GG6UU!7.F1[O__D#'`
M2(UT)`1(C3U1'0``Z!WM__](A<!T"P^V`(3`=`0\,'4/QP63?````````.EL
M____QP6$?````0```.E9____Z&K2__]F+@\?A```````\P\>^D%72&/"059)
MB<9!54%428G\54B-;SA32(GS2(/L"$B+=RA(BU<PC0S&2#GQ2(E/*$B#T@!(
MP>@=2`'02(E',$AC1WB%P`^%Z0```$&#_C\/CB<!``!!@^Y`18GW0<'O!D6-
M;P%)P>4&20'=D/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/
M;UOP#Q%=,.@1UO__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$B-30A(@^'X
M28E4)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+=!4`
M2(DT$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`=.%!
M#[95`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;U`````2(U\!0!(B=Y!
M*<5%.?5%#T_N36/]3(GZZ/71__]!BT0D>$0!Z$&)1"1X@_A`=9),B>=%*>Y,
M`?OH-=7__^G/_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6____Y#S
M#Q[Z059,C78X055!5%5(B?532(M&*$B)^T2+9BA$BVXP2,'H`X/@/T$/S$$/
MS8U(`4B8QD0&.(!(8\%,`?"#^3@/CA`!``"^0````"G.=`\QTHG1@\(!Q@0(
M`#GR<O-(B>_HJ-3__V8/[\`/$44X2<=&,`````!!#Q%&$$$/$48@1(EM<$B)
M[T2)973H?M3__TB+10!(B>](P>@8B`-(BT4`2,'H$(A#`4B+10"(8P)(BT4`
MB$,#2(M%"$C!Z!B(0P1(BT4(2,'H$(A#!4B+10B(8P9(BT4(B$,'2(M%$$C!
MZ!B(0PA(BT402,'H$(A#"4B+11"(8PI(BT40B$,+2(M%&$C!Z!B(0PQ(BT48
M2,'H$(A##4B+11B(8PY(BT48B$,/2(M%($C!Z!B(0Q!(BT4@2,'H$(A#$4B+
M12"(8Q)(BT4@B$,36UU!7$%=05[I6\[__P\?`+HX````,?\IRH/Z"')*B=%(
MQP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"\?[__X/B^#'`
MB<:#P`A(B3PQ.=!R\^G:_O__#Q^$``````#VP@1U(X72#X3%_O__Q@``]L("
M#X2Y_O__,<EFB4P0_NFM_O__#Q\`QP``````QT00_`````#IE_[__P\?1```
M\P\>^D%7059!54%455-,C9PD`(#__TB![``0``!(@PPD`$PYW'7O2('L:`$`
M`$R--?,8``!(B7PD"$B-;"0L3(GW2(GN9$B+!"4H````2(F$)%B!``!(C06X
M&0``2,=$)&``````2,>$))@`````````2,=$)$``````2(E$)%!(C06?&```
M2(E$)%A(C04F&0``2(E$)'A(C05[&0``2(F$)(````!(C04H&0``2(F$)(@`
M``!(C05E&0``2(F$))````!(C04]&0``2(E$)#!(C05.&0``2(E$)#@QP.AL
MZ/__2(7`=`R`.`!)B<0/A:L$``#H%L[__XG'Z)_,__](A<`/A.X#``!,BRA-
MA>T/A.(#``!,B>_HLLS__TB-?``!Z`C,__]%#[9%`$F)Q$6$P'0Z38GG2(T=
M\!@``)!%#[;`3(G_2(G9O@$```!(Q\+_____,<!)@\4!28/'`N@+SO__10^V
M10!%A,!UT4B-7"1P2(T]11@``.L4#Q\`2(M["$B#PPA(A?\/A$<!``!(B>XQ
MP.BUY___28G%2(7`=-V`.`!TV$B)Q^APZ/__A<!TS$R)[^CTS/__28G`2(7`
M#X00`0``#Q^$``````!,B<=,B40D$.CSR___3(GG2(G#Z.C+__]$C;P#!`0`
M`$UC_TR)_^@UR___051,C0T\%P``2(T-*1@``$F)Q4B-!>D7``!(Q\+_____
MO@$```!03(M$)"!,B>\QP.@_S?__3(GOOL`!``#HHLW__U]!6(/X_W42Z%7,
M__]$BPA!@_D1#X44`P``2(V$)*````!,B>](B<9(B40D$.B0S/__B<.%P`^$
MQ@```$B+1"0(38GHO@$```!%,>1(C15/&```2(L(2(L%'78``$B+.#'`Z#O*
M__](BX0D6($``&1(*P0E*`````^%P04``$B!Q&B!``!,B>!;74%<05U!7D%?
MPP\?@`````!,C2TV%P``,=OK&0\?1```2&/#3(MLQ%!-A>UT.T&`?0``=#1,
MB>^#PP'H&>?__X7`=-U,B>_HG<O__TF)P$B%P`^%L?[__TACPTR+;,10387M
M=<D/'T``13'`Z9C^__\/'X0``````(N$)+@````E`/```#T`0```#X4C____
M1(ND)+P```#HK,O__T$YQ`^%#?___XN$)+@````E_P$``#W``0``#X7V_O__
M3(G_Z*3)__](B>Y(C3UC%@``28G$,<#HL.7__TB)QDB%P`^$-`(``$B+1"0(
M2(LXZ$?M__])B<=(A<`/A!L"``!,B?_H`\K__TB)PH/X`WX[2)A(C35?%@``
M2(E4)!A)C7P'_.CSRO__A<!U'TB+5"08@_H$#X3'`P``C4+[2)A!@#P'+P^$
MMP,``)"+!<IT``"#^/\/A&$#``!(C3U9%0``A<`/A,D!``!(C36W%0``,<!(
MC2TX%@``Z#WI__],C3T:%@``Z$')__]52,?"_____TV)Z%!,C0W>%```O@$`
M``!,B>=(C0WE%0``,<#H^,K__UA:ZT0/'T``Z!O*__^#.!%U2.@!R?__@\,!
M2(/L"$V)Z%5,C0V?%```3(GYO@$```!32,?"_____TR)YU`QP.BTRO__2(/$
M(+[``0``3(GGZ!/+__^#^/]TKDR)[^CFR/__3(GW3(GF,<#HF>C__TR)Y^@!
M]?__Z;']__\/'T``,=M(C3T(%0``ZQ(/'T0``$ACPTB+?,0P2(7_=#A(B>XQ
MP(/#`>@NY/__2(7`=.&`.`!TW$B)Q^A\R?__28G%2(7`#X76^___2&/#2(M\
MQ#!(A?]UR+\-````3(TMM10``.C2Q___0;A3````28G$Z<G[__](BT0D"$V)
MZ+X!````13'D2(T5'14``$B+"$B+!2MS``!(BS@QP.A)Q___Z0G]__\/'T``
M2(G'Z$CT__](BX0D6($``&1(*P0E*`````^%O@(``$B!Q&B!``!,B>=;74%<
M05U!7D%?Z=C(__\/'X0``````$B+1"0(3(LXZ=C]___'!>ER````````3(G_
M,?8QP.@MR/__2(T]=1,``(G%A<`/A!K^__^Z`@```$C'QN[___^)Q^@IR?__
M2(V<)%`!``"Z!@```(GO2(G>Z-+&__^`O"10`0```'4.@+PD40$``$,/A+\!
M```QTC'VB>_H[\C__[^`````Z,7&__](QP`!(T5G28G'N(FKS>])B4<(2"V+
MSA)728E'$$@%\@08*TG'1QAV5#(028E'($G'1R@`````2<=',`````!!QT=X
M`````.L/#Q]``$B)WDR)_^BM]?__N@"```!(B=Z)[^@^QO__B<*%P'_@B>](
MC:PD,`$``$B-'483``#HPL7__TR)_DB)[^@7]___2(V$),@```!,BWPD$$B)
M1"0(#Q]$``!$#[9%`$R)_TB)V;X!````2,?"_____S'`2(/%`4F#QP+H.LC_
M_TPY?"0(==-(C04R$P``QH0DR`````!0_W0D&$B-#>\2``!-B>A,B><QP+X!
M````3(T-U!$``$C'PO_____H^,?__UE>Z5/]__^02(T]^!$``#'`2(GN2(E\
M)`CHNN'__TB%P`^$3O[__P^V`(3`#X1#_O__/#`/A#O^___'!21Q```!````
M2(M\)`CI:/S__TB+1"0(2(M0"$B%T@^$./S__TB)UTB)5"0(Z.O%__](@_@#
M#X8A_/__2(M4)`A(C35'$@``2(U\`OSHV\;__TB+5"0(A<!,#T3ZZ?O[__^`
MO"12`0``00^%,_[__X"\)%,!``!##X4E_O__@+PD5`$``$@/A1?^__^`O"15
M`0``10^%"?[__[H"````2,?&QO___XGOZ/#&__^Z*0```$B)WHGOZ*'$__](
MC04`$@``4%/IU/[__^A.QO__9F8N#Q^$```````/'P#S#Q[Z055!5%532(/L
M&$B+'<MO``!D2(L$)2@```!(B40D"#'`BSOH9,;__XL[2(G%Z%K&__\/MI6P
M````2(UL)`1(C3V*$```2(GNB)"Q````,<#H9^#__TB%P'0)@#@Q#X29`0``
M,<#H,NO__XL[Z!O&__^Y`P```+H!````2(TU7Q$``$B)Q^@RQ/__28G$2(7`
M=#1(BT`0BSM,BRCH[,7__TB-%3P1``!(B<=,B>[H.L3__TF+1"003(L@0?9$
M)`Y`#X5V`0``BSOHO\7__[D#````N@$```!(C34*$0``2(G'Z-;#__])B<1(
MA<!T.DB-/:@/``!(B>XQP.B]W___BSM)B<5(A<`/A/\```!)BT0D$$R+(.AR
MQ?__3(GJ2(G'3(GFZ,3#__^+.^A=Q?__N@$```!(C36O$```2(G'Z+G"__^+
M.TF)Q.@_Q?__3(GF2(T5J!```$B)Q^B-P___BSOH)L7__TB)[DB-/20/``#&
M@+$`````,<#H/M___TB)!0=O``!)B<1(A<!T/[[``0``3(GGZ++%__^-4`&#
M^@%V"8/X$0^%J````$B+1"0(9$@K!"4H````#X6Q````2(/$&%M=05Q!7<-F
MD$B+/<%N``#HE/7__TB)!:UN``!)B<1(A<!UIDB-/;80```QP.BGQ/__#Q^`
M`````(!X`0`/A&3^___I6/[__Y!(BP6!;@``3(LH28M$)!!,BR#H:<3__TR)
M[DR)Y^C.X?__Z?7^__]F#Q^$``````"+.^A)Q/__3(GF2(G'Z-[#___I<_[_
M_XG!2(L%.&X``$R)XDB-/680``!(BS`QP.@LQ/__Z,?#__\/'X``````\P\>
M^DB+#;UM``#IX,'___,/'OI(@^P(2(/$",,`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!,1%],24)205)97U!!5$@`<&%R+0`M
M90`M+0!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP
M+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`U-0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF
M:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC
M:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO
M9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I
M;&5N86UE72D["GT*?2!]"D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP
M;5QN(CL*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ
M<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I
M.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=
M*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G
M/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@
M9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I
M="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US(%]&2#L*
M;7D@)&UA9VEC7W!O<R`]("1S:7IE("T@)'-I>F4@)2`D8VAU;FM?<VEZ93L@
M(R!.3U1%.B`D;6%G:6-?<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC
M7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA
M9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0II9B`H)&UA9VEC7W!O<R`\(#`I
M('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)
M0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H
M(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0[
M"FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T
M(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0@+2`D;V9F<V5T+"`P.PHD9&%T85]P;W,@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M
M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H
M97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD
M9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M
M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA
M;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*=6YL97-S("@D8G5F
M(&5Q(")02UPP,#-<,#`T(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E
M<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@
M("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R
M;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;
M0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A
M=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS
M92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E
M<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?
M:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O
M0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\
M+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@
M("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L
M("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C
M*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y
M(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO
M72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN
M97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT
M9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L
M("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T
M:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO
M=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D
M;W5T(ET["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96X@;7D@)'1H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1T:"D[
M"F-L;W-E("1T:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,"`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")<,$-!0TA%(CL*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`K(&QE;F=T:"@D8V%C:&5?;F%M92D@+2!L96YG=&@H)&QO861E
M<BD["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"G!A8VLH)TXG+"`D;V9F<V5T
M*2P*)%!!4E]-04=)0RD*)B8@)&9H+3YC;&]S90IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E
M<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["B1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["F]U=',H(E)E861I;F<@345402YY;6PN+BXB
M*3L*:68@*&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z7',J)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PII9B`H;7D@*"1C;&5A;BD@/2`D;65T82`]?B`O7EQS*V-L96%N
M.B`H+BHI)"]M*2!["B1C;&5A;B`]?B`O7EQS*GQ<<RHD+V<["B1%3E9[4$%2
M7T-,14%.?2`](#$@:68@)&-L96%N.PI]"GT*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U
M=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA
M;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92![
M"FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X
M+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM
M?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F
M("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,
M3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,````!&P,[\```
M`!T```",</__)`$```QT__],`0``''3__V0!``",=___<`4``,QY__\,`0``
MO'K__WP!``#LD/__S`$``+R1__\8`@``3)+__SP"``"\D___@`(``"R4__^<
M`@``')7__]P"``!LE___*`,``*R7__]``P``C)C__WP#``"<F/__D`,``+R:
M___T`P``[)K__P@$``#,F___.`0``-R@__^$!```7*'__Z`$``",H?__N`0`
M`)RB__\4!0``_*+__RP%```,I/__G`4``*RE___H!0``G*?__R@&```LL/__
M!`<``*RR__]$!P``%``````````!>E(``7@0`1L,!PB0`0``%````!P```"X
M>/__)@````!$!Q``````)````#0```!@;___@`,````.$$8.&$H/"W<(@``_
M&CHJ,R0B`````!0```!<````N'+__Q```````````````!0```!T````L'+_
M_W`#`````````````$P```",````.'G__S`6````0@X0CP))#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1P[0!0,(%@H..$$.,$$.*$(.($(.&$(.$$(."$$+
M````2````-P````8C___S0````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`"`````H`0``G(__
M_X,`````00X0A@)*#K`!`G$*#A!!#@A!"T````!,`0``")#__VP!````0@X0
MC@)"#AB-`T(.((P$00XHA@5!#C"#!D<.T`%^"@XP00XH00X@0@X80@X00@X(
M2PL`&````)`!```TD?__8@````!%#A"#`@)$#@@``#P```"L`0``B)'__^T`
M````0@X0C@)"#AB-`T(.((P$00XHA@5'#J@@20[`(`*_"@XH00X@0@X80@X0
M0@X(0PM(````[`$``#B2__]!`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9$#CB#!T<.8`,5`0H..$$.,$$.*$(.($(.&$(.$$(."$4+%````#@"```\
ME/__-P````!(#A!9#@@`.````%`"``!DE/__V`````!&#A",`D$.&(8#00X@
M@P1'#J`@3`Z@0$D.P$`"IPH.($0.&$$.$$(."$$+$````(P"```(E?__"0``
M``````!@````H`(```25__\2`@```$8.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T<.N"!,#H`B`G$*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P*O#H@B
M3@Z0(EH.B")!#H`B````$`````0#``#`EO__)0`````````L````&`,``-R6
M___<`````$X.$(8"`EX*Q@X(3`MY"@X(1PM("L8."$4+2PX(Q@!(````2`,`
M`(R7__\$!0```$8.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!TL.4`.F
M!`H..$T.,$$.*$(.($(.&$(.$$(."$4+&````)0#``!0G/__?`````!(#B!M
M"@X(2PL``!0```"P`P``M)S__R$`````2`X06`X(`%@```#(`P``S)S__PL!
M````1@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"0@H.*$8.($$.&$(.$$(."$@+
M9`H.*$$.($$.&$(.$$(."$8+80Y(20Y08PY(00Y`````%````"0$``"`G?__
M6`````!(#A`"3PX(0````#P$``#(G?__!@$```!&#A",`D0.&(8#00X@@P1$
M#C`"9PH.($$.&$$.$$(."$8+<PH.($0.&$$.$$(."$8+```H````@`0``!1R
M__\R`@```$8.$(P"00X8A@-$#E`#A`$*#AA$#A!"#@A!"T@```"L!```:)[_
M_Y\!````1@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D4..(,'1PY``N$*#CA!
M#C!!#BA"#B!"#AA"#A!"#@A#"P`\````^`0``+R?___K`0```$8.$(X"1@X8
MC0-"#B",!$$.*(8%1`XP@P8#-@$*#BA!#B!"#AA"#A!"#@A("P``V````#@%
M``!LH?__@@@```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=(#`NX
M@`)1#0='#J"#`@//`0ZH@P)E#K"#`ET.J(,"0@Z@@P("@@H..$0.,$$.*$(.
M($(.&$(.$$(."$@+`W@!#JB#`DL.L(,"7@ZH@P)!#J"#`EP.J(,"1`ZP@P)0
M#KB#`DL.P(,"2PZ@@P(#!@$*#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P-M`0ZH
M@P)$#K"#`F@.J(,"00Z@@P("_0H.J(,"00ZP@P)%"P```#P````4!@``(*G_
M_WD"````1@X0C0)"#AB,`T$.((8$00XH@P5$#D`#N0$*#BA!#B!!#AA"#A!"
M#@A#"P`````0````5`8``&"K__\0````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$`J`````````"H````````!`````````.4"`````````0````````#U
M`@````````P``````````"`````````-`````````%!B````````&0``````
M``#`RP```````!L`````````"``````````:`````````,C+````````'```
M```````(`````````/7^_V\`````L`,````````%`````````&`-````````
M!@````````"0!`````````H`````````=@0````````+`````````!@`````
M````%0````````````````````,`````````T,T````````"`````````"@%
M````````%``````````'`````````!<`````````F!0````````'````````
M`!@3````````"`````````"``0````````D`````````&``````````>````
M``````@`````````^___;P`````!```(`````/[__V\`````F!(```````#_
M__]O``````$`````````\/__;P````#6$0```````/G__V\`````!```````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-#+````````
M`````````````````````#`@````````0"````````!0(````````&`@````
M````<"````````"`(````````)`@````````H"````````"P(````````,`@
M````````T"````````#@(````````/`@`````````"$````````0(0``````
M`"`A````````,"$```````!`(0```````%`A````````8"$```````!P(0``
M`````(`A````````D"$```````"@(0```````+`A````````P"$```````#0
M(0```````.`A````````\"$`````````(@```````!`B````````("(`````
M```P(@```````$`B````````4"(```````!@(@```````'`B````````@"(`
M``````"0(@```````*`B````````L"(```````#`(@```````-`B````````
MX"(```````#P(@`````````C````````$",````````@(P```````#`C````
M````0",```````!0(P```````&`C````````<",```````"`(P```````)`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````V'(```````!'
M0T,Z("A58G5N='4@,3$N,RXP+31U8G5N='4Q*2`Q,2XS+C```"YS:'-T<G1A
M8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M
M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT
M`"YI;FET`"YP;'0N9V]T`"YP;'0N<V5C`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@`````````8`P```````!@#````````'```````
M``````````````$````````````````````3````!P````(`````````.`,`
M```````X`P```````#`````````````````````(````````````````````
M)@````<````"`````````&@#````````:`,````````D````````````````
M````!````````````````````#D````'`````@````````",`P```````(P#
M````````(`````````````````````0```````````````````!'````]O__
M;P(`````````L`,```````"P`P```````-P`````````!@`````````(````
M````````````````40````L````"`````````)`$````````D`0```````#0
M"`````````<````!````"``````````8`````````%D````#`````@``````
M``!@#0```````&`-````````=@0```````````````````$`````````````
M``````!A````____;P(`````````UA$```````#6$0```````+P`````````
M!@`````````"``````````(`````````;@```/[__V\"`````````)@2````
M````F!(```````"```````````<````!````"````````````````````'T`
M```$`````@`````````8$P```````!@3````````@`$````````&````````
M``@`````````&`````````"'````!````$(`````````F!0```````"8%```
M`````"@%````````!@```!@````(`````````!@`````````D0````$````&
M```````````@`````````"`````````;````````````````````!```````
M`````````````(P````!````!@`````````@(````````"`@````````@`,`
M`````````````````!``````````$`````````"7`````0````8`````````
MH",```````"@(P```````!`````````````````````0`````````!``````
M````H`````$````&`````````+`C````````L",```````!P`P``````````
M````````$``````````0`````````*D````!````!@`````````@)P``````
M`"`G````````,#L``````````````````!````````````````````"O````
M`0````8`````````4&(```````!08@````````T````````````````````$
M````````````````````M0````$````"``````````!P`````````'``````
M``"2/P``````````````````"````````````````````+T````!`````@``
M``````"4KP```````)2O````````]`````````````````````0`````````
M``````````#+`````0````(`````````B+````````"(L````````&@&````
M```````````````(````````````````````U0````X````#`````````,#+
M````````P+L````````(````````````````````"``````````(````````
M`.$````/`````P````````#(RP```````,B[````````"```````````````
M``````@`````````"`````````#M````!@````,`````````T,L```````#0
MNP`````````"````````!P`````````(`````````!``````````FP````$`
M```#`````````-#-````````T+T````````P`@``````````````````"```
M```````(`````````/8````!`````P``````````T`````````#`````````
M(`````````````````````@```````````````````#\````"`````,`````
M````(-`````````@P````````$`0```````````````````@````````````
M`````````0$```$````P````````````````````(,`````````E````````
M`````````````0`````````!``````````$````#````````````````````
L`````$7`````````"@$```````````````````$`````````````````````
